==> hk2-api-1.6.11-sources.jar: org/glassfish/hk2/Services.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2;

import org.jvnet.hk2.annotations.Contract;

import java.util.Collection;

/**
 * Services is the registry for HK2 services. In earlier versions this was
 * referred to as the Habitat.
 * 
 * <p/>
 * Services can be dynamically added to this instance or looked up. Services can also
 * be implicitly added to HK2 by annotating the class with the &#064;Service
 * annotation.
 * 
 * <p/>
 * Services are organized in a parent-child structure.  Whenever services are being
 * located, a parent search first algorithm is used.
 *
 */
// TODO: this currently jettisons Listeners and Trackers, found in Habitat but not here
@Contract
public interface Services extends Locator {

    /**
     * Retrieves the default Services registry. This can be thought of as the root.
     * 
     * @return the default, root service registry
     */
    Services getDefault();
    
    /**
     * Retrieves the service registry given a module name.
     * 
     * @param moduleName the module name, or null for the default services registry
     * @return the service registry, or null if the service registry does not exist
     */
    Services getServices(String moduleName);

    /**
     * Allow dynamic additions to this service registry.
     *
     * @return a {@link DynamicBinderFactory} instance to add services after
     * this services has been initialized.
     */
    DynamicBinderFactory bindDynamically();
    
    /**
     * Retrieve the collection of all existing bindings in this, and only this, service
     * registry.
     * 
     * @return a non-null collection of service bindings
     */
    Collection<Binding<?>> getDeclaredBindings();
    
    /**
     * Retrieve the collection of existing bindings in this, and only this, service
     * registry that matches the {@link Descriptor}.
     * 
     * <p/>
     * A {@link Descriptor} matches if it's attributes are equal, or specified as null.
     * A Descriptor with all null attributes will therefore match all services in this
     * services registry.
     * 
     * @param descriptor the descriptor used for matching, or null for all
     * @return a non-null collection of service bindings matching the argument
     */
    Collection<Binding<?>> getDeclaredBindings(Descriptor descriptor);

    /**
     * Retrieve the collection of all existing bindings in this as well as in parent
     * service registries.
     * 
     * @return a non-null collection of service bindings
     */
    Collection<Binding<?>> getBindings();

    /**
     * Retrieve the collection of existing bindings in this as well as in parent
     * service registries that matches the {@link Descriptor}.
     * 
     * <p/>
     * A {@link Descriptor} matches if it's attributes are equal, or specified as null.
     * A Descriptor with all null attributes will therefore match all services in this
     * services registry.
     * 
     * @param descriptor the descriptor used for matching, or null for all
     * @return a non-null collection of service bindings matching the argument
     */
    Collection<Binding<?>> getBindings(Descriptor descriptor);
    
}

==> hk2-api-1.6.29-sources.jar: org/glassfish/hk2/Services.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://glassfish.dev.java.net/public/CDDL+GPL_1_1.html
 * or packager/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at packager/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * Oracle designates this particular file as subject to the "Classpath"
 * exception as provided by Oracle in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.hk2;

import org.jvnet.hk2.annotations.Contract;

import java.util.Collection;

/**
 * Services is the registry for HK2 services. In earlier versions this was
 * referred to as the Habitat.
 * 
 * <p/>
 * Services can be dynamically added to this instance or looked up. Services can also
 * be implicitly added to HK2 by annotating the class with the &#064;Service
 * annotation.
 * 
 * <p/>
 * Services are organized in a parent-child structure.  Whenever services are being
 * located, a parent search first algorithm is used.
 *
 */
// TODO: this currently jettisons Listeners and Trackers, found in Habitat but not here
@Contract
public interface Services extends Locator {

    /**
     * Retrieves the default Services registry. This can be thought of as the root.
     * 
     * @return the default, root service registry
     */
    Services getDefault();
    
    /**
     * Retrieves the service registry given a module name.
     * 
     * @param moduleName the module name, or null for the default services registry
     * @return the service registry, or null if the service registry does not exist
     */
    Services getServices(String moduleName);

    /**
     * Allow dynamic additions to this service registry.
     *
     * @return a {@link DynamicBinderFactory} instance to add services after
     * this services has been initialized.
     */
    DynamicBinderFactory bindDynamically();
    
    /**
     * Retrieve the collection of all registered bindings in this, and only this,
     * Services instance.
     * 
     * @return a non-null collection of service bindings
     */
    Collection<Binding<?>> getDeclaredBindings();
    
    /**
     * Retrieve the collection of registered bindings in this, and only this, Services
     * instance that match the {@link Descriptor} argument.
     * 
     * <p/>
     * A {@link Descriptor} matches if it's attributes are equal, or specified as null.
     * A Descriptor with all null attributes will therefore match all services in this
     * services registry.
     * 
     * @param descriptor the descriptor used for matching, or null for all
     * @return a non-null collection of service bindings matching the argument
     */
    Collection<Binding<?>> getDeclaredBindings(Descriptor descriptor);

    /**
     * Retrieve the collection of all registered bindings in this instance as well as
     * in the parent service instance(s).
     * 
     * @return a non-null collection of service bindings
     */
    Collection<Binding<?>> getBindings();

    /**
     * Retrieve the collection of existing bindings in this as well as in parent
     * service registries that matches the {@link Descriptor}.
     * 
     * <p/>
     * A {@link Descriptor} matches if it's attributes are equal, or specified as null.
     * A Descriptor with all null attributes will therefore match all services in this
     * services registry.
     * 
     * @param descriptor the descriptor used for matching, or null for all
     * @return a non-null collection of service bindings matching the argument
     */
    Collection<Binding<?>> getBindings(Descriptor descriptor);
    
}
